betty.ancestry.place_type.place_types module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.place_type.place_types module

Provide Betty’s ancestry place types.

class betty.ancestry.place_type.place_types.Borough

  Bases: `ShorthandPluginBase`, `PlaceType`

  A borough.

class betty.ancestry.place_type.place_types.Building

  Bases: `ShorthandPluginBase`, `PlaceType`

  A building.

class betty.ancestry.place_type.place_types.City

  Bases: `ShorthandPluginBase`, `PlaceType`

  A city.

class betty.ancestry.place_type.place_types.Country

  Bases: `ShorthandPluginBase`, `PlaceType`

  A country.

class betty.ancestry.place_type.place_types.County

  Bases: `ShorthandPluginBase`, `PlaceType`

  A county.

class betty.ancestry.place_type.place_types.Department

  Bases: `ShorthandPluginBase`, `PlaceType`

  A department.

class betty.ancestry.place_type.place_types.District

  Bases: `ShorthandPluginBase`, `PlaceType`

  A district.

class betty.ancestry.place_type.place_types.Farm

  Bases: `ShorthandPluginBase`, `PlaceType`

  A farm.

class betty.ancestry.place_type.place_types.Hamlet

  Bases: `ShorthandPluginBase`, `PlaceType`

  A hamlet.

class betty.ancestry.place_type.place_types.Locality

  Bases: `ShorthandPluginBase`, `PlaceType`

  A locality.

class betty.ancestry.place_type.place_types.Municipality

  Bases: `ShorthandPluginBase`, `PlaceType`

  A municipality.

class betty.ancestry.place_type.place_types.Neighborhood

  Bases: `ShorthandPluginBase`, `PlaceType`

  A neighborhood.

class betty.ancestry.place_type.place_types.Number

  Bases: `ShorthandPluginBase`, `PlaceType`

  A place number, e.g. a house or flat number.

class betty.ancestry.place_type.place_types.Parish

  Bases: `ShorthandPluginBase`, `PlaceType`

  A parish.

class betty.ancestry.place_type.place_types.Province

  Bases: `ShorthandPluginBase`, `PlaceType`

  A province.

class betty.ancestry.place_type.place_types.Region

  Bases: `ShorthandPluginBase`, `PlaceType`

  A region.

class betty.ancestry.place_type.place_types.State

  Bases: `ShorthandPluginBase`, `PlaceType`

  A state.

class betty.ancestry.place_type.place_types.Street

  Bases: `ShorthandPluginBase`, `PlaceType`

  A street.

class betty.ancestry.place_type.place_types.Town

  Bases: `ShorthandPluginBase`, `PlaceType`

  A town.

class betty.ancestry.place_type.place_types.Unknown

  Bases: `ShorthandPluginBase`, `PlaceType`

  A place of an unknown type.

class betty.ancestry.place_type.place_types.Village

  Bases: `ShorthandPluginBase`, `PlaceType`

  A village.